==> colour-science-0.3.0.tar.gz: colour-science-0.3.0/colour/models/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import absolute_import

from .rgb_colourspace import RGB_Colourspace
from .derivation import (
    normalised_primary_matrix,
    RGB_luminance_equation,
    RGB_luminance)
from .dataset import *  # noqa
from . import dataset
from .cie_xyy import (
    XYZ_to_xyY,
    xyY_to_XYZ,
    xy_to_XYZ,
    XYZ_to_xy)
from .cie_lab import XYZ_to_Lab, Lab_to_XYZ, Lab_to_LCHab, LCHab_to_Lab
from .cie_luv import (
    XYZ_to_Luv,
    Luv_to_XYZ,
    Luv_to_uv,
    Luv_uv_to_xy,
    Luv_to_LCHuv,
    LCHuv_to_Luv)
from .cie_ucs import XYZ_to_UCS, UCS_to_XYZ, UCS_to_uv, UCS_uv_to_xy
from .cie_uvw import XYZ_to_UVW
from .rgb import XYZ_to_RGB, RGB_to_XYZ
from .rgb import RGB_to_RGB
from .common import XYZ_to_sRGB
from .aces_rgb_idt import spectral_to_aces_relative_exposure_values

__all__ = ['RGB_Colourspace']
__all__ += ['normalised_primary_matrix',
            'RGB_luminance_equation',
            'RGB_luminance']
__all__ += dataset.__all__
__all__ += ['XYZ_to_xyY',
            'xyY_to_XYZ',
            'xy_to_XYZ',
            'XYZ_to_xy']
__all__ += ['XYZ_to_Lab', 'Lab_to_XYZ', 'Lab_to_LCHab', 'LCHab_to_Lab']
__all__ += ['XYZ_to_Luv',
            'Luv_to_XYZ',
            'Luv_to_uv',
            'Luv_uv_to_xy',
            'Luv_to_LCHuv',
            'LCHuv_to_Luv']
__all__ += ['XYZ_to_UCS', 'UCS_to_XYZ', 'UCS_to_uv', 'UCS_uv_to_xy']
__all__ += ['XYZ_to_UVW']
__all__ += ['XYZ_to_RGB', 'RGB_to_XYZ']
__all__ += ['RGB_to_RGB']
__all__ += ['XYZ_to_sRGB']
__all__ += ['spectral_to_aces_relative_exposure_values']

==> colour-science-0.3.3.tar.gz: colour-science-0.3.3/colour/models/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import absolute_import

from .cie_xyy import (
    XYZ_to_xyY,
    xyY_to_XYZ,
    xy_to_XYZ,
    XYZ_to_xy)
from .rgb import RGB_Colourspace
from .derivation import (
    normalised_primary_matrix,
    RGB_luminance_equation,
    RGB_luminance)
from .dataset import *  # noqa
from . import dataset
from .cie_lab import XYZ_to_Lab, Lab_to_XYZ, Lab_to_LCHab, LCHab_to_Lab
from .cie_luv import (
    XYZ_to_Luv,
    Luv_to_XYZ,
    Luv_to_uv,
    Luv_uv_to_xy,
    Luv_to_LCHuv,
    LCHuv_to_Luv)
from .cie_ucs import XYZ_to_UCS, UCS_to_XYZ, UCS_to_uv, UCS_uv_to_xy
from .cie_uvw import XYZ_to_UVW
from .rgb import XYZ_to_RGB, RGB_to_XYZ
from .rgb import RGB_to_RGB
from .common import XYZ_to_sRGB, sRGB_to_XYZ
from .aces_rgb_idt import spectral_to_aces_relative_exposure_values
from .ipt import XYZ_to_IPT, IPT_to_XYZ, IPT_hue_angle

__all__ = ['XYZ_to_xyY',
           'xyY_to_XYZ',
           'xy_to_XYZ',
           'XYZ_to_xy']
__all__ += ['RGB_Colourspace']
__all__ += ['normalised_primary_matrix',
            'RGB_luminance_equation',
            'RGB_luminance']
__all__ += dataset.__all__
__all__ += ['XYZ_to_Lab', 'Lab_to_XYZ', 'Lab_to_LCHab', 'LCHab_to_Lab']
__all__ += ['XYZ_to_Luv',
            'Luv_to_XYZ',
            'Luv_to_uv',
            'Luv_uv_to_xy',
            'Luv_to_LCHuv',
            'LCHuv_to_Luv']
__all__ += ['XYZ_to_UCS', 'UCS_to_XYZ', 'UCS_to_uv', 'UCS_uv_to_xy']
__all__ += ['XYZ_to_UVW']
__all__ += ['XYZ_to_RGB', 'RGB_to_XYZ']
__all__ += ['RGB_to_RGB']
__all__ += ['XYZ_to_sRGB', 'sRGB_to_XYZ']
__all__ += ['spectral_to_aces_relative_exposure_values']
__all__ += ['XYZ_to_IPT', 'IPT_to_XYZ', 'IPT_hue_angle']
